<?php

namespace Drupal\aws_cloud\Traits;

/**
 * The trait for AWS Cloud form.
 */
trait AwsCloudFormTrait {

  /**
   * Max length of the description of AWS Cloud security group (rule).
   *
   * @var int
   */
  public static $awsCloudSecurityGroupDescriptionMaxLength = 255;

  /**
   * Special characters in the description of AWS Cloud security group (rule).
   *
   * @var string
   */
  public static $awsCloudSecurityGroupDescriptionSpecialCharacters = '. _-:/()#,@[]+=&;{}!$*';

  /**
   * Get the pattern of a security group (rule) description.
   *
   * @return string
   *   A regexp pattern excluding ^ and $.
   */
  protected function getPatternOfSecurityGroupDescription(): string {
    return '[A-Za-z0-9' . preg_quote(self::$awsCloudSecurityGroupDescriptionSpecialCharacters, NULL) . ']*';
  }

  /**
   * Get VPC options.
   *
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return array
   *   The VPC options.
   */
  protected function getVpcOptions(string $cloud_context): array {
    $options = [];
    $vpcs = $this->entityTypeManager
      ->getStorage('aws_cloud_vpc')
      ->loadByProperties([
        'cloud_context' => $cloud_context,
      ]);

    foreach ($vpcs ?: [] as $vpc) {
      $name = NULL;
      foreach ($vpc->getTags() ?: [] as $tag) {
        if ($tag['item_key'] === 'Name') {
          $name = $tag['item_value'];
          break;
        }
      }

      $options[$vpc->getVpcId()] = ($name ?: $vpc->getVpcId()) . " ({$vpc->getVpcId()} | {$vpc->getCidrBlock()})";
    }

    natcasesort($options);
    return $options;
  }

  /**
   * Get availability zone options.
   *
   * @param string $cloud_context
   *   The cloud context.
   * @param bool $with_id
   *   Whether show ID or not.
   *
   * @return array
   *   The availability zone options.
   */
  protected function getAvailabilityZoneOptions(string $cloud_context, $with_id = FALSE): array {
    $options = [];
    $availability_zones = $this->entityTypeManager
      ->getStorage('aws_cloud_availability_zone')
      ->loadByProperties([
        'cloud_context' => $cloud_context,
      ]);
    foreach ($availability_zones ?: [] as $availability_zone) {
      $name = $with_id
        ? sprintf('%s (%s)', $availability_zone->getZoneName(), $availability_zone->getZoneId())
        : $availability_zone->getZoneName();

      $options[$availability_zone->getZoneName()] = $name;
    }

    natcasesort($options);
    return $options;
  }

}
