(function ($) {
  'use strict';

  const active_tab_observer = new MutationObserver((mutations) => {
    mutations.forEach((mutation) => {
      // changed vertival tab.
      updateSourcetypeOptions(mutation.target.value);
    });
  });
  const tab_configuration_observer = new MutationObserver((mutations) => {
    mutations.forEach((mutation) => {
      const className = mutation.target.className;
      if (className.includes('vertical-tabs-pane')) {
        // changed vertival tab.
        updateSourcetypeOptions(
          className.includes('active') ? 'git' : 'yml'
        );
      }
    });
  });
  active_tab_observer.observe(
    document.querySelector('.vertical-tabs__active-tab'),
    {
      attributes: true,
      attributeFilter: ['value']
    }
  );
  tab_configuration_observer.observe(
    document.querySelector('#edit-configuration-git'),
    {
      attributes: true,
      attributeFilter: ['class']
    }
  );

  const updateSourcetypeOptions = function (active_tab) {
    if (!active_tab) {
      return;
    }
    const field_source_type = $("select[name='field_source_type']")[0].value;
    const old_git_source_type = field_source_type === 'yml'
      ? document.getElementById("old_git_source_type").value
      : field_source_type;
    document.getElementById("old_git_source_type").value = old_git_source_type;
    $('#edit-field-source-type option').each(function () {
      const source_type = $(this).val();
      if ($(this).prop('selected')) {
        $(this).prop('selected', '');
      }
      // Hide _none.
      // And hide yml when the git tab is active.
      if (source_type == '_none'
        || active_tab.includes('git') && source_type === 'yml') {
        $(this).hide();
        return true;
      }
    });
    $('#edit-field-source-type option').each(function () {
      const source_type = $(this).val();

      // When the yml tab is active, select yml.
      // And when the git tab is active, select the value of field_source_type.
      if ((active_tab.includes('git') && old_git_source_type === source_type)
        || ((active_tab.includes('yml') || field_source_type === 'yml')
          && source_type === 'yml')) {
        $(this).prop('selected', 'selected');
        return false;
      }
    });
  };

})(jQuery);
